import React from 'react';
import Checkbox from '../checkbox';
import { OptionProps } from '../select/SelectProps';
declare type ExtendOption = {
    [key: string]: any;
};
interface Translation {
    sortTooltipAscend?: string;
    sortTooltipDescend?: string;
    sortTooltipCancel?: string;
    noData?: string;
    search?: string;
    reset?: string;
    colFilter?: string;
    checkboxSelection?: string;
    showAll?: string;
    hideAll?: string;
    rowFilter?: string;
    column?: string;
    operator?: string;
    value?: string;
    group?: string;
    resetFilterBtn?: string;
}
interface ControlCommon {
    translation?: Translation;
    showControlTitle?: boolean;
}
export interface ControlState {
    sorting: Sorting[];
    keyword: string;
    filters: Filter[];
}
export interface SortOptions {
    /** Sort function for ascending sort, see Array.sort's compareFunction */
    compare?: (a: any, b: any) => number;
    /** Config the priority of sort columns. (default: undefined) */
    multiple?: number;
    /** Default order of sorted values. (default: null) */
    defaultOrder?: SortType;
    /** Trigger when sort button click */
    onSort?: (colKey: string, order: SortType) => any;
    /** Supported sort way (default: both) */
    sortDirections?: 'ascend' | 'descend' | 'both';
}
export interface Sorting extends SortOptions {
    key: string;
    type: SortType;
}
export declare type SortType = 'ascend' | 'descend' | null;
export interface SearchControl {
    /** Auto apply search method (default: true) */
    autoSearch?: boolean;
    /** Fields used to search when autoSearch = false (default: all) */
    fields?: 'all' | string[];
    /** Auto search when typing with (debounce: 250ms) */
    searchOnTyping?: boolean;
    onSearch?: (keyword: string) => any;
    onReset?: () => any;
}
export declare type FilterType = 'number' | 'text' | 'date';
export interface FilterField {
    key: string;
    title: string;
    type: FilterType | OptionProps[];
}
export interface Filter {
    id: string;
    column?: string;
    op?: string;
    value?: any;
    logical?: string;
}
export interface FilterItemProp {
    filter: Filter;
    fields: FilterField[];
    hideDelIcon?: boolean;
    onFilterChange: (id: string, changedFilter: any) => void;
    onDelete: (id: string) => void;
}
export declare type RowFilterControl = {
    [key: string]: FilterType | OptionProps[];
};
export interface TableSearchProps extends ControlCommon {
    control: SearchControl;
    onAutoSearch: (keyword: string) => void;
}
export interface TableColFilterProps extends ControlCommon {
    selection?: boolean;
    columns: Array<Pick<TableColumn, 'key' | 'title'>>;
    onFilter: (hiddenCols: string[]) => void;
}
export interface TableRowFilterProps extends ControlCommon {
    control: RowFilterControl;
    columns: Array<Pick<TableColumn, 'key' | 'title'>>;
    onFilter: (filters: Filter[]) => any;
}
export interface TableRow extends ExtendOption {
    key?: string | number;
}
export interface TableColumn {
    /** Unique key of this column */
    key: string;
    /** Title of this column */
    title: string;
    /** th colSpan, set to 0, the cell will not be rendered. (default: -1) */
    colSpan?: number;
    /** Renderer of the table cell. The return value should be a ReactNode (default: undefined) */
    render?: (value: any, record: TableRow, index: number) => React.ReactNode;
    /** The specify which way that column is aligned (default: left) */
    align?: 'left' | 'center' | 'right';
    /** The className of this column */
    className?: string;
    /** Setup sort option */
    sorter?: SortOptions;
    /** Set max width to enable text-overflow: ellipsis, -1 to disabled. (default: -1) */
    maxWidth?: number;
}
export interface TableProps {
    columns: TableColumn[];
    rows?: TableRow[];
    /** Specify field in row is unique key (default: 'key') */
    keyField?: string;
    /** Border style (default: undefined) */
    bordered?: 'row' | 'column' | 'both';
    /** Change background color when hover (default: false) */
    hoverable?: boolean;
    /** Use striped to add zebra-striping to any table row within the tbody (default: undefined) */
    striped?: 'odd' | 'even';
    /** If true, compact vertical padding designed for keyboard and mouse input is used for the list and list items. The prop is available to descendant components as the dense context. (default: false) */
    dense?: boolean;
    /** Set the header sticky. (default: false) */
    stickyHeader?: boolean;
    /** Add table header */
    header?: React.ReactNode;
    /** Add class name, style to the root element */
    className?: string;
    style?: React.CSSProperties;
    /** (default: "No data available in table") */
    noData?: React.ReactNode;
    /** Allow row selection (default: selection: false, allowSelectAll: true) */
    selection?: boolean;
    allowSelectAll?: boolean;
    CheckboxProps?: React.ComponentProps<typeof Checkbox>;
    onRowSelectChange?: (selected: TableRow[], record?: TableRow) => any;
    /** Search control */
    searchControl?: SearchControl;
    /** Column filter control (default: false) */
    columnFilterControl?: boolean;
    /** Row filter control (default: false) */
    rowFilterControl?: RowFilterControl;
    /** Controls whether the control title is show (default: false) */
    showControlTitle?: boolean;
    /** Controls whether the reset filter button is show (default: true) */
    showResetFilter?: boolean;
    /** Support translate */
    translation?: Translation;
    /** The ref is forwarded to the root element. */
    ref?: React.Ref<HTMLDivElement>;
}
export {};
